@@ -1,16 +1,16 @@
 # Copyright (c) HashiCorp, Inc.
 # SPDX-License-Identifier: BUSL-1.1
 
-Vagrant.require "digest/sha1"
-Vagrant.require "log4r"
-Vagrant.require "pathname"
-Vagrant.require "uri"
+require "digest/sha1"
+require "log4r"
+require "pathname"
+require "uri"
 
-Vagrant.require "vagrant/box_metadata"
-Vagrant.require "vagrant/util/downloader"
-Vagrant.require "vagrant/util/file_checksum"
-Vagrant.require "vagrant/util/file_mutex"
-Vagrant.require "vagrant/util/platform"
+require "vagrant/box_metadata"
+require "vagrant/util/downloader"
+require "vagrant/util/file_checksum"
+require "vagrant/util/file_mutex"
+require "vagrant/util/platform"
 
 module Vagrant
   module Action
@@ -292,7 +292,7 @@ module Vagrant
             # If we have only one provider in the metadata, just use that
             # provider.
             metadata_provider = metadata_version.provider(
-              metadata_version.providers.first, architecture)
+              metadata_version.providers(architecture).first, architecture)
           else
             providers = metadata_version.providers(architecture).sort
 
